@@ -155,8 +155,6 @@ NMreadParsText <- function(file,lines,format,
     OMEGA <- NULL
     SIGMA <- NULL
 
-    
-
     if(missing(file)) file <- NULL
     if(missing(lines)) lines <- NULL
     
@@ -319,10 +317,17 @@ NMreadParsText <- function(file,lines,format,
         dt.lines[,text.clean:=text]
 ### We want to keep comments - that's what we want to process
         dt.lines[,text.clean:=sub("^ *;.*","",text.clean)]
+### remove tabulators. Is this necessary?
+        dt.lines[,text.clean:=gsub("\\t","",text.clean)]
         dt.lines[,text.clean:=sub(paste0("\\$",section),"",text.clean,ignore.case=TRUE)]
-        dt.lines[,text.clean:=gsub("BLOCK(.+)","",text.clean)]
+### old line, dropping any row that contains BLOCK and anything after 
+        ## dt.lines[,text.clean:=gsub("BLOCK(.+)","",text.clean)]
+### suggested by Brian Reilly. Will keep SAME after removing BLOCK(.+)
+        ## dt.lines[,text.clean:=gsub("BLOCK\\(.+\\)","",text.clean)]
+### slightly modified by Philip to support BLOCK and BLOCK(n)
+        dt.lines[,text.clean:=gsub("BLOCK(\\(.+\\))*","",text.clean)]
         dt.lines[,text.clean:=sub("^ *$","",text.clean)]
-## drop empty lines
+        ## drop empty lines
         ## drop empty lines. An empty line contains only " " and ;
         dt.lines[,text.clean:=gsub("^[\\s;]+$","",text.clean,perl=TRUE)]
         
@@ -334,8 +339,14 @@ NMreadParsText <- function(file,lines,format,
         dt.pars <- rbindlist(lapply(1:nrow(dt.lines.reduced),function(Nrow){
             fun.get.fields(dt.lines.reduced[Nrow,text.clean],res.fields)[,linenum:=dt.lines.reduced[Nrow,linenum]]
         }),
-            fill=TRUE)
-        colnames(dt.pars) <- c(res.fields$fields[1:(ncol(dt.pars)-1)],"linenum")
+        fill=TRUE)
+
+        
+        cnames.pars <- colnames(dt.pars)
+        n.newnames <- min(length(res.fields$fields), (ncol(dt.pars)-1))
+        cnames.pars[cnames.pars!="linenum"][1:n.newnames] <- res.fields$fields[1:n.newnames]
+        colnames(dt.pars) <- cnames.pars
+        ## colnames(dt.pars) <- c(res.fields$fields[1:(ncol(dt.pars)-1)],"linenum")
         
 
         dt.pars[,par.type:=toupper(section)]
@@ -393,9 +404,12 @@ NMreadParsText <- function(file,lines,format,
     if("THETA"%in%auto.idx){
         
         elems.theta <- NMreadInits(lines=lines,section="THETA",return="all",as.fun="data.table")$elements
-        thetas <- merge(thetas[,setdiff(colnames(thetas),c("i","j")),with=FALSE],
-                        elems.theta[type.elem=="init",.(par.type,linenum,i)],
-                        by=c("par.type","linenum"),all.x=TRUE)
+        thetas <- merge(
+            thetas[,setdiff(colnames(thetas),c("i","j")),with=FALSE]
+           ,
+            elems.theta[type.elem=="init"
+                       ,.(par.type,linenum,i)],
+            by=c("par.type","linenum"),all.x=TRUE)
     }
     if("OMEGA"%in%auto.idx){
         
@@ -409,7 +423,7 @@ NMreadParsText <- function(file,lines,format,
         elems.sigma <- NMreadInits(lines=lines,section="SIGMA",return="all",as.fun="data.table")$elements
         sigmas <- merge(sigmas[,setdiff(colnames(sigmas),c("i","j")),with=FALSE],
                         elems.sigma[type.elem=="init",.(par.type,linenum,i,j)],
-by=c("par.type","linenum"),all.x=TRUE)
+                        by=c("par.type","linenum"),all.x=TRUE)
     }
 
 
@@ -464,7 +478,7 @@ by=c("par.type","linenum"),all.x=TRUE)
     cols.last <- intersect(c("par.type","i","j","col.idx","parameter",col.model),colnames(pt1))
     setcolorder(pt1,c(setdiff(colnames(pt1),cols.last),cols.last))
     
-    
+    setindex(pt1,NULL)    
     as.fun(pt1)
 }
 
