@@ -184,7 +184,7 @@ compareCols <- function(...,list.data,keep.names=TRUE,test.equal=FALSE,diff.only
             res.dims <- dims(list.data=dots)
             message("Dimensions:")
             ## message(print(as.fun(res.dims)))
-            message_dt(res.dims,as.fun=as.fun)
+            message_dt(res.dims)
         }
 
         if(nrow(dt.cols)==0&&ndots==1){
@@ -205,7 +205,7 @@ compareCols <- function(...,list.data,keep.names=TRUE,test.equal=FALSE,diff.only
                 ## message("[[[[[[")
                 ## message(paste(capture.output(print(as.fun(dt.cols))),collapse="\n"))
                 ## print(dt.cols)
-                message_dt(dt.cols,as.fun=as.fun)
+                message_dt(dt.cols)
                 message()
                 if(nrow(dt.cols.full[nu==1&n==ndots])){
                     messageWrap(paste0("\nColumns where no differences were found: ",paste(dt.cols.full[nu==1&n==ndots,column],collapse=", "),"."),fun.msg=message)
@@ -213,7 +213,7 @@ compareCols <- function(...,list.data,keep.names=TRUE,test.equal=FALSE,diff.only
             } else {
                 message("\nOverview of all columns:")
                 ## message(print(as.fun(dt.cols)))
-                message_dt(dt.cols,as.fun=as.fun)
+                message_dt(dt.cols)
             }
         }
         return(invisible(as.fun(dt.cols)))
