@@ -127,14 +127,7 @@ print.summary_NMdata <- function(x,...){
     if(!is.data.table(vars)){
         vars <- as.data.table(vars)
     }
-    
-    tabs.out <- copy(x$tables)
-    if(!is.data.table(tabs.out)){
-        tabs.out <- as.data.table(tabs.out)
-    }
 
-    
-    
     vars[,included:=!is.na(COLNUM)]
     vars <- mergeCheck(vars,data.table(included=c(TRUE,FALSE),
                                        inc=c("included","not")),
@@ -148,7 +141,11 @@ print.summary_NMdata <- function(x,...){
     ## calc number of used and available rows
     ## Since this is based on NMinfo(res,"columns"), we know the table is used
     
-    
+
+    tabs.out <- copy(x$tables)
+    if(!is.data.table(tabs.out)){
+        tabs.out <- as.data.table(tabs.out)
+    } 
     tabs.out[,tabn:=1:.N]
     ## assuming that all ID's present somewhere in output is present in all output tables
     ## tabs.out[source=="output",nid:=x$N.ids[NMOUT=="Output",N.ids]]
@@ -160,6 +157,7 @@ print.summary_NMdata <- function(x,...){
     vars.sum2[source=="output",nrow.used:=pmin(nrow,x$N.row[nmout==TRUE,N.rows])]
     vars.sum2[source=="input",nrow.used:=pmin(nrow,x$N.row[,sum(N.rows)])]
     vars.sum2[,nid.used:=pmin(nid,x$N.id[,sum(N.ids)])]
+    vars.sum2[source=="output",file:=paste(file,"(output)")]
     vars.sum2[source=="input",file:=paste(file,"(input)")]
     
     
@@ -206,21 +204,27 @@ print.summary_NMdata <- function(x,...){
     n5[is.na(n5)] <- 0
     
     ## model name
-    cat("Model: ",x$details$model,"\n")
+    ## cat("Model: ",x$details$model,"\n")
+    message("Model: ",x$details$model,"\n")
 
     ## overview of processed tables
-    cat("\nUsed tables, contents shown as used/total:\n")
-    print(vars.sum2,row.names=FALSE,print.keys=FALSE,class=FALSE)
+    ## cat("\nUsed tables, contents shown as used/total:\n")
+    ## message("Used tables, N of rows, columns and distinct ID's shown as used/available")
+    message("Number of rows, columns and distinct ID's\nN\'s by source table, shown as used/available:")
+    ## print(vars.sum2,row.names=FALSE,print.keys=FALSE,class=FALSE)
+    message_dt(vars.sum2)
 
     if(x$details$input.used){
         if(x$details$merge.by.row){
-            cat("\nInput and output data merged by:",x$details$col.row,"\n")
+            ## cat("\nInput and output data merged by:",x$details$col.row,"\n")
+            message("Input and output data merged by:",x$details$col.row,"\n")
         } else {
             message("Input and output data combined by translation of
 Nonmem data filters.")
         }
     } else {
-        cat("Input data not used.\n")
+        ## cat("Input data not used.\n")
+        message("Input data not used.\n")
     }
     
     ## cat("\nNumbers of rows and subjects\n")
@@ -248,8 +252,9 @@ Nonmem data filters.")
             setcolorder(evids2,
                         neworder=intersect(cc(EVID,CMT,"input-only","output","result"),colnames(evids2)))
 
-            cat("Distribution of rows on event types in returned data:\n")
-            print(evids2,row.names=FALSE,print.keys=FALSE,class=FALSE)
+            message("Distribution of rows on event types\nShown for output tables and result:")
+            ## print(evids2,row.names=FALSE,print.keys=FALSE,class=FALSE)
+            message_dt(evids2)
         })
     }        
 
