@@ -16,8 +16,12 @@ test_that("basic",{
 test_that("basic - lst mode",{
 
     fileRef <- "testReference/NMextractText_2.rds"
-    file.lst <- "testData/nonmem/xgxr004.lst"
-    res1 <- NMextractText(file.lst,section="THETA",char.section="\\$",type="lst")
 
+    ## readRDS(fileRef)
+    file.lst <- "testData/nonmem/xgxr004.lst"
+    res1 <- NMextractText(file.lst,section="THETA",char.section="\\$",type="mod")
     expect_equal_to_reference(res1,fileRef,version=2)
+
+    res1 <- NMextractText(file.lst,section="THETA",char.section="\\$",type="lst")
+    expect_null(res1)
 })
