@@ -167,7 +167,7 @@ $SIGMA 1
     lines <- strsplit(text,split="\n")[[1]]
 
     res <- NMreadParsText(lines=lines,format="%init;[%num];%symbol (%unit)",
-                          format.omega="%init            ; %symbol                ; %num ; %type   ; %label ; %unit",field.idx="num"
+                          format.omega="%init  ; %symbol     ; %num ; %type   ; %label ; %unit",field.idx="num"
                           ## ,use.idx=T
                           )
 
@@ -183,6 +183,25 @@ $SIGMA 1
 })
 
 
+text <- c("
+; matches format
+$THETA  (.1)             ;[1]; LTVKA (mL/h)
+$OMEGA  BLOCK(3)
+0.126303  ;    IIV.CL  ; 1   ;IIV     ;Between-subject variability on CL;-
+
+0.024  0.127  ;    IIV.V2  ; 2   ;IIV     ;Between-subject variability on V2;-
+  0.2 0.2   0.38  ; IIV.CL.V3.cov  ; 3 ;IIV     ;Covariance of BSV on CL and V3;-
+$OMEGA 0 FIX ; IIV.KA ; 4  ;IIV     ;Between-subject variability on KA;-
+$SIGMA 1
+")
+lines <- strsplit(text,split="\n")[[1]]
+
+res <- NMreadParsText(lines=lines,format="%init;[%num];%symbol (%unit)",
+                      format.omega="%init  ; %symbol     ; %num ; %type   ; %label ; %unit",field.idx="num"
+                      ## ,use.idx=T
+                      )
+
+
 test_that("OMEGA SAME",{
 
 ### BLOCK SAME are being skipped
@@ -199,8 +218,8 @@ $THETA
 $OMEGA  0.08   ;    IIV.TH1  ; 1  ;IIV
  $OMEGA  BLOCK(1)
  0.547465  ; IOV.TH1  ; 2 ;IOV
-$OMEGA  BLOCK(1) SAME
-$OMEGA  BLOCK(1) SAME")
+$OMEGA  BLOCK(1) SAME; IOV.TH1 ; 3; IOV2
+$OMEGA  BLOCK SAME")
 
     lines <- strsplit(text,split="\n")[[1]]
 
@@ -235,3 +254,66 @@ test_that("muref SAEM - format.omega=NULL",{
     expect_equal(res1,res2)
     
 })
+
+### redundant, see "OMEGA SAME"
+## test_that("Occassion variability",{
+##     fileRef <- "testReference/NMreadParText_09.rds"
+##     file.mod <- "testData/nonmem/xgxr044.mod"
+##     NMdataConf(reset=T)
+##     NMdataConf(as.fun="data.table")
+
+##     res1 <- NMreadParsText(file.mod,format="%init;%symbol")
+##     expect_equal_to_reference(res1,fileRef)
+##     if(F){
+##         res1
+##         readRDS(fileRef)
+##     }
+## })
+
+
+test_that("OMEGA SAME with linebreks",{
+
+### BLOCK SAME are being skipped
+    
+    fileRef <- "testReference/NMreadParText_09.rds"
+
+    NMdataConf(reset=T)
+    NMdataConf(as.fun="data.table")
+
+
+    text <- c("
+$THETA
+(0, 4.4)	; CL		; none		; 1	; struct	; Clearance	; L/h
+$OMEGA
+0.15		; IIV.KA	; lognormal 	; 7	; IIV		; Between-subject variability on KA 	; -
+$OMEGA BLOCK(1)
+0.15		; IOV1.KA	; lognormal 	; 8	; IOV		; Between-occasion variability on KA 	; -
+$OMEGA BLOCK(1)
+SAME ; IOV2.KA	; lognormal 	; 9	; IOV		; Between-occasion variability on KA 	; -
+$OMEGA BLOCK(1) SAME ; IOV3.KA	; lognormal 	; 10	; IOV		; Between-occasion variability on KA 	; -
+$OMEGA BLOCK(1)
+0.2		; IIV.D1	; lognormal 	; 11	; IIV		; Between-subject variability on D1 	; -
+$OMEGA BLOCK(1)
+0.3		; IOV1.D1	; lognormal 	; 12	; IOV		; Between-occasion variability on D1 	; -
+$OMEGA BLOCK(1) SAME ; IOV2.D1	; lognormal 	; 13	; IOV		; Between-occasion variability on D1 	; -
+$OMEGA BLOCK(1) SAME ; IOV3.D1	; lognormal 	; 14	; IOV		; Between-occasion variability on D1 	; -
+")
+
+
+    lines <- strsplit(text,split="\n")[[1]]
+
+    res <- NMreadParsText(lines=lines,
+                          format="%init;%symbol ;%trans; %idx; %panel; %label;%unit"
+                          )
+
+    expect_equal_to_reference(res,fileRef)
+
+    if(F){
+        ref <- readRDS(fileRef)
+        ref
+        res
+        
+    }
+
+
+})
