@@ -5,7 +5,7 @@ test_that("basic",{
     fileRef <- "testReference/listMissings_1.rds"
 
     pk <- readRDS(file="testData/data/xgxr2.rds")
-    miss <- listMissings(pk)
+    miss <- listMissings(pk,quiet=TRUE)
 
     expect_equal_to_reference(miss,fileRef,version=2)
 
